.. gshapa documentation master file, created by
   sphinx-quickstart on Tue Dec 17 08:07:21 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to gshapa's documentation!
==================================

.. image:: _static/logo.webp
   :width: 150
   :align: center

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   gshapa



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
